.. designate_ui documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

================================================
 Welcome to designatedashboard's documentation!
================================================

.. toctree::
   :maxdepth: 2

   readme
   install/index
   user/index
   contributor/index

.. rubric:: Indices and tables

* :ref:`genindex`
* :ref:`search`
